@@ -1224,10 +1224,10 @@ gnome_print_pdf_close_write_last_objects (GnomePrintPdf *pdf)
 static void
 gnome_print_embed_all_pdf_fonts (GnomePrintPdf *pdf)
 {
-	g_return_if_fail (pdf != NULL);
-
 	GList *list;
 
+	g_return_if_fail (pdf != NULL);
+
 	list = pdf->fonts;
 	while (list) {
 		GnomePrintPdfFont *font;
@@ -1684,7 +1684,7 @@ gnome_print_pdf_set_font_real (GnomePrintPdf *pdf, const GnomeFont *gnome_font,
 	GnomePrintPdfFont *font = NULL;
 	GnomeFontFace *face;
 	GList *needle;
-	guchar *encodedname;
+	guchar *encodedname = NULL;
 	gint i;
 
 	face = gnome_font->face;
