@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: ttcr.c,v 1.1 2004/06/21 20:39:07 kcsuresh Exp $ */
+/* $Id: ttcr.c,v 1.2 2004/07/21 16:42:25 jody Exp $ */
 /* @(#)ttcr.c 1.7 03/01/08 SMI */
 
 /**
@@ -277,7 +277,7 @@ void TrueTypeCreatorNewEmpty(uint32 tag, TrueTypeCreator **_this)
     TrueTypeCreator *ptr = smalloc(sizeof(TrueTypeCreator));
 
     ptr->tables = listNewEmpty();
-    listSetElementDtor(ptr->tables, TrueTypeTableDispose);
+    listSetElementDtor(ptr->tables, (GDestroyNotify)TrueTypeTableDispose);
 
     ptr->tag = tag;
 
@@ -326,7 +326,7 @@ int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
     byte *ttf;
     int i=0, n;
     TableEntry *te;
-    byte *head;     /* saved pointer to the head table data for checkSumAdjustment calculation */
+    byte *head = NULL;     /* saved pointer to the head table data for checkSumAdjustment calculation */
     
     if ((n = listCount(_this->tables)) == 0) return SF_TTFORMAT;
 
